AlsaCaptureBridge

Struct AlsaCaptureBridge 

pub struct AlsaCaptureBridge { /* private fields */ }
Converts ALSA capture buffers into PCM stream packets.

Implementations

Source

impl AlsaCaptureBridge

pub fn new(queue: HostCallbackQueue, spec: PcmSpec) -> Self

Builds a capture bridge that pushes packets onto queue in spec.

pub fn capture_interleaved_f32(&self, samples: &[f32]) -> Result<PushResult>

Captures interleaved F32 samples into a PCM packet on the queue.

The sample count must be a multiple of the spec’s channel count. The packet is encoded in the spec’s sample format (F32 directly, or I16 by conversion). Returns the queue’s PushResult.

pub fn capture_interleaved_i16(&self, samples: &[i16]) -> Result<PushResult>

Captures interleaved I16 samples into a PCM packet on the queue.

The sample count must be a multiple of the spec’s channel count. The packet is encoded in the spec’s sample format (I16 directly, or F32 by conversion). Returns the queue’s PushResult.

pub fn spec(&self) -> PcmSpec

Returns the PCM spec the bridge encodes packets in.